@@ -14,25 +14,31 @@
 
 # Presence handler
 
+from __future__ import annotations
+
+from typing import Any
+from typing import Optional
+from typing import Union
+
 import time
 
 import nbxmpp
 from nbxmpp.namespaces import Namespace
+from nbxmpp.protocol import JID
+from nbxmpp.structs import PresenceProperties
 from nbxmpp.structs import StanzaHandler
-from nbxmpp.const import PresenceType
 
 from gajim.common import app
 from gajim.common import idle
+from gajim.common import types
 from gajim.common.events import PresenceReceived
 from gajim.common.events import ShowChanged
-from gajim.common.events import SubscribePresenceReceived
 from gajim.common.events import SubscribedPresenceReceived
+from gajim.common.events import SubscribePresenceReceived
 from gajim.common.events import UnsubscribedPresenceReceived
 from gajim.common.i18n import _
-from gajim.common.structs import PresenceData
-from gajim.common.const import KindConstant
-from gajim.common.const import ShowConstant
 from gajim.common.modules.base import BaseModule
+from gajim.common.structs import PresenceData
 
 
 class Presence(BaseModule):
@@ -42,12 +48,17 @@ class Presence(BaseModule):
         'subscribed',
     ]
 
-    def __init__(self, con):
+    def __init__(self, con: types.Client) -> None:
         BaseModule.__init__(self, con)
 
         self.handlers = [
             StanzaHandler(name='presence',
                           callback=self._presence_received,
+                          typ='available',
+                          priority=50),
+            StanzaHandler(name='presence',
+                          callback=self._presence_received,
+                          typ='unavailable',
                           priority=50),
             StanzaHandler(name='presence',
                           callback=self._subscribe_received,
@@ -67,16 +78,21 @@ class Presence(BaseModule):
                           priority=49),
         ]
 
-        self._presence_store = {}
+        self._presence_store: dict[JID, PresenceData] = {}
 
         # keep the jids we auto added (transports contacts) to not send the
         # SUBSCRIBED event to GUI
-        self.automatically_added = []
+        self.automatically_added: list[str] = []
 
         # list of jid to auto-authorize
-        self._jids_for_auto_auth = set()
+        self._jids_for_auto_auth: set[str] = set()
+
+    def _presence_received(self,
+                           _con: types.xmppClient,
+                           stanza: nbxmpp.protocol.Presence,
+                           properties: PresenceProperties
+                           ) -> None:
 
-    def _presence_received(self, _con, stanza, properties):
         if properties.from_muc:
             # MUC occupant presences are already handled in MUC module
             return
@@ -95,10 +111,6 @@ class Presence(BaseModule):
         contact = self._con.get_module('Contacts').get_contact(properties.jid)
         contact.update_presence(presence_data)
 
-        if properties.type == PresenceType.ERROR:
-            self._log.info('Error: %s %s', properties.jid, properties.error)
-            return
-
         if properties.is_self_presence:
             app.ged.raise_event(ShowChanged(account=self._account,
                                             show=properties.show.value))
@@ -116,7 +128,7 @@ class Presence(BaseModule):
         if properties.type.is_unavailable:
             show = 'offline'
 
-        event_attrs = {
+        event_attrs: dict[str, Any] = {
             'account': self._account,
             'conn': self._con,
             'stanza': stanza,
@@ -142,24 +154,11 @@ class Presence(BaseModule):
 
         app.ged.raise_event(PresenceReceived(**event_attrs))
 
-        self._log_presence(properties)
-
-    def _log_presence(self, properties):
-        if not app.settings.get('log_contact_status_changes'):
-            return
-
-        show = ShowConstant[properties.show.name]
-        if properties.type.is_unavailable:
-            show = ShowConstant.OFFLINE
-
-        app.storage.archive.insert_into_logs(self._account,
-                                             properties.jid.bare,
-                                             time.time(),
-                                             KindConstant.STATUS,
-                                             message=properties.status,
-                                             show=show)
-
-    def _subscribe_received(self, _con, _stanza, properties):
+    def _subscribe_received(self,
+                            _con: types.xmppClient,
+                            _stanza: nbxmpp.protocol.Presence,
+                            properties: PresenceProperties
+                            ) -> None:
         jid = properties.jid.bare
         fjid = str(properties.jid)
 
@@ -190,7 +189,11 @@ class Presence(BaseModule):
 
         raise nbxmpp.NodeProcessed
 
-    def _subscribed_received(self, _con, _stanza, properties):
+    def _subscribed_received(self,
+                             _con: types.xmppClient,
+                             _stanza: nbxmpp.protocol.Presence,
+                             properties: PresenceProperties
+                             ) -> None:
         jid = properties.jid.bare
         self._log.info('Received Subscribed: %s', properties.jid)
         if jid in self.automatically_added:
@@ -202,11 +205,19 @@ class Presence(BaseModule):
             jid=properties.jid))
         raise nbxmpp.NodeProcessed
 
-    def _unsubscribe_received(self, _con, _stanza, properties):
+    def _unsubscribe_received(self,
+                              _con: types.xmppClient,
+                              _stanza: nbxmpp.protocol.Presence,
+                              properties: PresenceProperties
+                              ) -> None:
         self._log.info('Received Unsubscribe: %s', properties.jid)
         raise nbxmpp.NodeProcessed
 
-    def _unsubscribed_received(self, _con, _stanza, properties):
+    def _unsubscribed_received(self,
+                               _con: types.xmppClient,
+                               _stanza: nbxmpp.protocol.Presence,
+                               properties: PresenceProperties
+                               ) -> None:
         self._log.info('Received Unsubscribed: %s', properties.jid)
         app.ged.raise_event(UnsubscribedPresenceReceived(
             conn=self._con,
@@ -214,17 +225,23 @@ class Presence(BaseModule):
             jid=properties.jid.bare))
         raise nbxmpp.NodeProcessed
 
-    def unsubscribed(self, jid):
+    def unsubscribed(self, jid: Union[JID, str]) -> None:
         self._log.info('Unsubscribed: %s', jid)
-        self._jids_for_auto_auth.discard(jid)
+        self._jids_for_auto_auth.discard(str(jid))
         self._nbxmpp('BasePresence').unsubscribed(jid)
 
-    def unsubscribe(self, jid):
+    def unsubscribe(self, jid: Union[JID, str]) -> None:
         self._log.info('Unsubscribe from %s', jid)
-        self._jids_for_auto_auth.discard(jid)
+        self._jids_for_auto_auth.discard(str(jid))
         self._nbxmpp('BasePresence').unsubscribe(jid)
 
-    def subscribe(self, jid, msg=None, name=None, groups=None, auto_auth=False):
+    def subscribe(self,
+                  jid: Union[JID, str],
+                  msg: Optional[str] = None,
+                  name: Optional[str] = None,
+                  groups: Optional[list[str]] = None,
+                  auto_auth: bool = False
+                  ) -> None:
         self._log.info('Request Subscription to %s', jid)
 
         if auto_auth:
@@ -235,9 +252,16 @@ class Presence(BaseModule):
                                                status=msg,
                                                nick=app.nicks[self._account])
 
-    def get_presence(self, to=None, typ=None, priority=None,
-                     show=None, status=None, nick=None, caps=True,
-                     idle_time=False):
+    def get_presence(self,
+                     to: Optional[str] = None,
+                     typ: Optional[str] = None,
+                     priority: Optional[int] = None,
+                     show: Optional[str] = None,
+                     status: Optional[str] = None,
+                     nick: Optional[str] = None,
+                     caps: bool = True,
+                     idle_time: bool = False
+                     ) -> nbxmpp.Presence:
         if show not in ('chat', 'away', 'xa', 'dnd'):
             # Gajim sometimes passes invalid show values here
             # until this is fixed this is a workaround
@@ -265,7 +289,7 @@ class Presence(BaseModule):
 
         return presence
 
-    def send_presence(self, *args, **kwargs):
+    def send_presence(self, *args: Any, **kwargs: Any) -> None:
         if not app.account_is_connected(self._account):
             return
         presence = self.get_presence(*args, **kwargs)
