@@ -19,12 +19,12 @@ from datetime import datetime
 
 from gi.repository import Gtk
 
-from gajim.common.i18n import _
 from gajim.common.const import AvatarSize
+from gajim.common.i18n import _
 
-from .widgets import SimpleLabel
-from .widgets import DateTimeLabel
-from .base import BaseRow
+from gajim.gtk.conversation.rows.base import BaseRow
+from gajim.gtk.conversation.rows.widgets import DateTimeLabel
+from gajim.gtk.conversation.rows.widgets import SimpleLabel
 
 
 class MUCJoinLeft(BaseRow):
