@@ -49,9 +49,11 @@ from gajim.common.preview import Preview
 from gajim.common.structs import URI
 from gajim.common.util.text import escape_iri_path_segment
 
+from gajim.gtk.const import MuteState
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.structs import AddChatActionParams
 from gajim.gtk.structs import ChatListEntryParam
+from gajim.gtk.structs import MuteContactParam
 from gajim.gtk.structs import RemoveHistoryActionParams
 from gajim.gtk.structs import RetractMessageParam
 from gajim.gtk.util import GajimMenu
@@ -73,7 +75,6 @@ def get_self_contact_menu(contact: types.BareContact) -> GajimMenu:
 
     params = RemoveHistoryActionParams(account=account, jid=jid)
     menu.add_item(_('Remove History…'), 'app.remove-history', params)
-    menu.add_item(_('Search…'), 'win.search-history', None)
     return menu
 
 
@@ -81,7 +82,6 @@ def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
     account = contact.account
 
     menu = GajimMenu()
-    menu.add_item(_('Details'), 'win.show-contact-info')
     menu.add_item(_('Block Contact…'),
                   f'app.{account}-block-contact',
                   str(contact.jid))
@@ -92,8 +92,6 @@ def get_singlechat_menu(contact: types.BareContact) -> GajimMenu:
     menu.add_item(_('Start Voice Call…'), 'win.start-voice-call')
     menu.add_item(_('Start Video Call…'), 'win.start-video-call')
 
-    menu.add_item(_('Search…'), 'win.search-history', None)
-
     if can_add_to_roster(contact):
         params = AccountJidParam(account=account, jid=contact.jid)
         menu.add_item(_('Add to Contact List…'), 'win.add-to-roster', params)
@@ -106,9 +104,7 @@ def get_private_chat_menu(contact: types.GroupchatParticipant) -> GajimMenu:
 
     value = GLib.Variant('as', [''])
 
-    menu.add_item(_('Details'), 'win.show-contact-info')
     menu.add_item(_('Upload File…'), 'win.send-file-httpupload', value)
-    menu.add_item(_('Search…'), 'win.search-history')
 
     if can_add_to_roster(contact):
         params = AccountJidParam(account=contact.account, jid=contact.jid)
@@ -129,11 +125,9 @@ def get_send_file_submenu() -> GajimMenu:
 
 def get_groupchat_menu(contact: GroupchatContact) -> GajimMenu:
     menuitems: MenuItemListT = [
-        (_('Details'), 'win.show-contact-info', None),
         (_('Change Nickname…'), 'win.muc-change-nickname', None),
         (_('Request Voice'), 'win.muc-request-voice', None),
         (_('Execute Command…'), 'win.muc-execute-command', ''),
-        (_('Search…'), 'win.search-history', None)
     ]
 
     return GajimMenu.from_list(menuitems)
@@ -532,6 +526,21 @@ def get_chat_list_row_menu(workspace_id: str,
         params = AccountJidParam(account=account, jid=jid)
         menu.add_item(_('Mark as read'), 'win.mark-as-read', params)
 
+    if contact.is_muted:
+        menu.add_item(
+            _('Unmute Chat'),
+            'app.mute-chat',
+            MuteContactParam(account=account,
+                             jid=jid,
+                             state=MuteState.UNMUTE))
+    else:
+        submenu = menu.add_submenu(_('Mute Chat'))
+        for state, label in MuteState.iter():
+            submenu.add_item(
+                label,
+                'app.mute-chat',
+                MuteContactParam(account=account, jid=jid, state=state))
+
     return menu
 
 
@@ -672,7 +681,13 @@ def get_chat_row_menu(contact: types.ChatContactT,
 
     format_string = app.settings.get('date_time_format')
     timestamp_formatted = timestamp.strftime(format_string)
-    copy_text = f'{timestamp_formatted} - {name}: {text}'
+
+    copy_text = f'{timestamp_formatted} - {name}: '
+    if text.startswith(('```', '> ')):
+        # Prepend a line break in order to keep code block/quotes rendering
+        copy_text += '\n'
+    copy_text += text
+
     menu_items.append(
         (p_('Message row action', 'Copy'),
          'win.copy-message',
@@ -715,8 +730,7 @@ def get_chat_row_menu(contact: types.ChatContactT,
 
         if disco_info.has_message_moderation and is_allowed:
             show_retract = True
-    if show_retract:
-        assert stanza_id is not None
+    if show_retract and stanza_id is not None:
         param = RetractMessageParam(
             account=contact.account,
             jid=contact.jid,
@@ -726,6 +740,12 @@ def get_chat_row_menu(contact: types.ChatContactT,
             'win.retract-message',
             param))
 
+    if log_line_id is not None:
+        menu_items.append(
+            (p_('Message row action', 'Delete Message Locally…'),
+            'win.delete-message-locally',
+            GLib.Variant('u', log_line_id or 0)))
+
     return GajimMenu.from_list(menu_items)
 
 
@@ -772,23 +792,17 @@ def get_format_menu() -> GajimMenu:
     return GajimMenu.from_list(menuitems)
 
 
-def get_workspace_menu(workspace_id: str, has_unread: bool) -> GajimMenu:
+def get_workspace_menu(workspace_id: str) -> GajimMenu:
     remove_action = 'win.dummy'
     if app.settings.get_workspace_count() > 1:
         remove_action = 'win.remove-workspace'
 
     menuitems: MenuItemListT = [
+        (_('Mark as read'), 'win.mark-workspace-as-read', workspace_id),
         (_('Edit…'), 'win.edit-workspace', workspace_id),
         (_('Remove'), remove_action, workspace_id),
     ]
 
-    if has_unread:
-        menuitems.insert(
-            0,
-            (_('Mark as read'),
-             'win.mark-workspace-as-read',
-             workspace_id))
-
     return GajimMenu.from_list(menuitems)
 
 
